NamedInputModule

Trait NamedInputModule 

pub trait NamedInputModule: Module {
    // Required method
    fn forward_named(
        &self,
        input: &Variable,
        refs: &HashMap<String, Variable>,
    ) -> Result<Variable>;
}
Module that can receive additional named inputs via graph using().

Required Methods

fn forward_named( &self, input: &Variable, refs: &HashMap<String, Variable>, ) -> Result<Variable>

Forward pass with additional named inputs from tagged graph nodes. refs maps tag names to their current values, as wired by FlowBuilder::using().

Implementors